@@ -3,13 +3,13 @@ import sys
 
 import termcolor
 
-from .lib.argumentparser import ExecuteArgumentParser
 from .exceptions import B5ExecutionError
+from .lib.argumentparser import ExecuteArgumentParser
 from .lib.module import load_module
 from .lib.state import State
 
 
-def main():
+def main() -> None:
     try:
         parser = ExecuteArgumentParser('b5-execute', 'b5-execute is not intended to be called directly!')
         parser.add_arguments()
