@@ -1,5 +1,4 @@
 import argparse
-from typing import List, Optional, Type
 
 from .detect import DETECT
 
@@ -9,7 +8,7 @@ class ArgumentParser:
             self,
             prog: str = 'b5',
             description: str = '',
-            formatter_class: Type[argparse.HelpFormatter] = argparse.ArgumentDefaultsHelpFormatter,
+            formatter_class: type[argparse.HelpFormatter] = argparse.ArgumentDefaultsHelpFormatter,
     ) -> None:
         self.parser = argparse.ArgumentParser(
             prog=prog,
@@ -20,7 +19,7 @@ class ArgumentParser:
 
     def parse(
             self,
-            arguments: Optional[List[str]] = None,
+            arguments: list[str] | None = None,
             help_as_default: bool = False,
     ) -> argparse.Namespace:
         if help_as_default:
@@ -45,7 +44,8 @@ class MainArgumentParser(ArgumentParser):
         Possible command line argument:
         --config -c Path to config (inside run path)
         --taskfile -t Path to Taskfile (inside run path)
-        --project-path -p Project path if not part of parent paths, normally b5 tries to get the project path by itself
+        --project-path -p Project path if not part of parent paths, normally b5 tries to get the project path
+          by itself
         --run-path -r Path inside the project b5 will execute in (cd into)
         --detect -d Version Control System detection (git or hg)
         --shell -s Shell to run the generated script in (should be bash)
