@@ -1,12 +1,12 @@
 import os
 
 
-def detect_git(path):
+def detect_git(path: str) -> bool:
     git_path = os.path.join(path, '.git')
     return os.path.exists(git_path) and os.path.isdir(git_path)
 
 
-def detect_hg(path):
+def detect_hg(path: str) -> bool:
     git_path = os.path.join(path, '.hg')
     return os.path.exists(git_path) and os.path.isdir(git_path)
 
@@ -17,7 +17,7 @@ DETECT = {
 }
 
 
-def detect_project_path(path, detect):
+def detect_project_path(path: str, detect: str) -> str:
     path = os.path.realpath(path)
     while not DETECT[detect](path):
         parent_path = os.path.dirname(path)
