@@ -5,16 +5,14 @@ from types import ModuleType
 def import_string(dotted_path: str) -> ModuleType:
     try:
         module_path, class_name = dotted_path.rsplit('.', 1)
-    except ValueError:
-        raise ImportError("%s doesn't look like a module path" % dotted_path)
+    except ValueError as e:
+        raise ImportError(f"{dotted_path} doesn't look like a module path") from e
 
     module = import_module(module_path)
 
     try:
         return getattr(module, class_name)
-    except AttributeError:
+    except AttributeError as e:
         raise ImportError(
-            'Module "%s" does not define a "%s" attribute/class' % (
-                module_path, class_name,
-            ),
-        )
+            f'Module "{module_path}" does not define a "{class_name}" attribute/class',
+        ) from e
