@@ -1,11 +1,10 @@
 import os
-from typing import Dict, List
 
 from ..exceptions import B5ExecutionError
 from .state import State
 
 
-def find_taskfiles(state: State, taskfiles: List[str]) -> List[Dict[str, str]]:
+def find_taskfiles(state: State, taskfiles: list[str]) -> list[dict[str, str]]:
     run_path = os.path.realpath(state.run_path)
     found_taskfiles = []
     for taskfile in taskfiles:
@@ -16,5 +15,5 @@ def find_taskfiles(state: State, taskfiles: List[str]) -> List[Dict[str, str]]:
                 'path': taskfile_path,
             })
     if not found_taskfiles:
-        raise B5ExecutionError('No Taskfiles found, tried %s inside %s' % (', '.join(taskfiles), run_path))
+        raise B5ExecutionError(f"No Taskfiles found, tried {', '.join(taskfiles)} inside {run_path}")
     return found_taskfiles
