@@ -12,6 +12,8 @@ def ensure_config_version(config_version_str: str) -> None:
     try:
         config_version = version.parse(config_version_str)
     except TypeError as O_o:
-        raise B5ExecutionError('Version in config.yml (%s) could not be parsed' % config_version_str) from O_o
+        raise B5ExecutionError(f'Version in config.yml ({config_version_str}) could not be parsed') from O_o
     if config_version > B5_VERSION:
-        raise B5ExecutionError('config.yml requires more recent version of b5 (>=%s), aborting' % config_version_str)
+        raise B5ExecutionError(
+            f'config.yml requires more recent version of b5 (>={config_version_str}), aborting',
+        )
